==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm2015/lib/ScatterSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ScatterBase } from "./ScatterBase";
import { markType } from "igniteui-angular-core";
import { ScatterFrame } from "./ScatterFrame";
import { ScatterBaseView } from "./ScatterBaseView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-angular-core";
/**
 * @hidden
 */
export let ScatterSeries = /*@__PURE__*/ (() => {
    class ScatterSeries extends ScatterBase {
        constructor() {
            super();
            this.ab = ScatterSeries.$;
            this.sb = new ScatterFrame();
            this.sd = new ScatterFrame();
            this.r9 = new ScatterFrame();
        }
        get_c5() {
            return true;
        }
        by() {
            return new ScatterSeriesView(this);
        }
        g0() {
            return 0.7;
        }
        qf() {
            if (this.qe == 0) {
                return 2;
            }
            return super.qf();
        }
        l4(a) {
            super.l4(a);
            this.vg = a;
        }
    }
    ScatterSeries.$t = markType(ScatterSeries, 'ScatterSeries', ScatterBase.$);
    return ScatterSeries;
})();
/**
 * @hidden
 */
export let ScatterSeriesView = /*@__PURE__*/ (() => {
    class ScatterSeriesView extends ScatterBaseView {
        constructor(a) {
            super(a);
            this.df = null;
            this.df = a;
        }
        as() {
            super.as();
            if (!this.q) {
                this.b1.ql = Defaults.e;
            }
        }
        af() {
            let a = new Color();
            a.colorString = "rgba(95,95,95,0.5)";
            this.e.ph = a;
            this.e.g1 = 3;
            this.e.g2 = 2;
            this.e.g3 = 2;
            this.e.fb = false;
        }
    }
    ScatterSeriesView.$t = markType(ScatterSeriesView, 'ScatterSeriesView', ScatterBaseView.$);
    return ScatterSeriesView;
})();

==> igniteui-angular-charts-17.2.0-beta.0.tgz: package/esm2015/lib/ScatterSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ScatterBase } from "./ScatterBase";
import { markType } from "igniteui-angular-core";
import { ScatterFrame } from "./ScatterFrame";
import { ScatterBaseView } from "./ScatterBaseView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-angular-core";
/**
 * @hidden
 */
export let ScatterSeries = /*@__PURE__*/ (() => {
    class ScatterSeries extends ScatterBase {
        constructor() {
            super();
            this.ab = ScatterSeries.$;
            this.v0 = new ScatterFrame();
            this.v2 = new ScatterFrame();
            this.vy = new ScatterFrame();
        }
        get_dx() {
            return true;
        }
        cg() {
            return new ScatterSeriesView(this);
        }
        iq() {
            return 0.7;
        }
        t4() {
            if (this.t3 == 0) {
                return 2;
            }
            return super.t4();
        }
        o0(a) {
            super.o0(a);
            this.ze = a;
        }
    }
    ScatterSeries.$t = markType(ScatterSeries, 'ScatterSeries', ScatterBase.$);
    return ScatterSeries;
})();
/**
 * @hidden
 */
export let ScatterSeriesView = /*@__PURE__*/ (() => {
    class ScatterSeriesView extends ScatterBaseView {
        constructor(a) {
            super(a);
            this.di = null;
            this.di = a;
        }
        au() {
            super.au();
            if (!this.q) {
                this.b4.ua = Defaults.e;
            }
        }
        af() {
            let a = new Color();
            a.colorString = "rgba(95,95,95,0.5)";
            this.e.s6 = a;
            this.e.ir = 3;
            this.e.is = 2;
            this.e.it = 2;
            this.e.gj = false;
        }
    }
    ScatterSeriesView.$t = markType(ScatterSeriesView, 'ScatterSeriesView', ScatterBaseView.$);
    return ScatterSeriesView;
})();
